@@ -1,7 +1,6 @@
 
 using System;
 using System.IO;
-using System.Collections;
 using System.Collections.Generic;
 using Mono.Unix;
 
@@ -31,7 +30,7 @@ namespace Tomboy
 			Preferences.SettingChanged += OnSettingChanged;
 		}
 
-		static void OnSettingChanged (object sender, GConf.NotifyEventArgs args)
+		static void OnSettingChanged (object sender, NotifyEventArgs args)
 		{
 			switch (args.Key) {
 			case Preferences.START_NOTE_URI:
@@ -78,9 +77,7 @@ public NoteManager (string directory) :
 
 		protected virtual AddinManager CreateAddinManager ()
 		{
-			string tomboy_conf_dir =
-			        Path.Combine (Environment.GetEnvironmentVariable ("HOME"),
-			                      ".tomboy");
+			string tomboy_conf_dir = Services.NativeApplication.ConfDir;
 
 			return new AddinManager (tomboy_conf_dir);
 		}
@@ -203,6 +200,8 @@ public NoteManager (string directory) :
 					            e.Message);
 				}
 			}
+			
+			notes.Sort (new CompareDates ());
 
 			// Update the trie so addins can access it, if they want.
 			trie_controller.Update ();
@@ -227,10 +226,12 @@ public NoteManager (string directory) :
 				}
 			}
 
-			// Make sure that a Start Note Uri is set in the preferences.  This
+			// Make sure that a Start Note Uri is set in the preferences, and
+			// make sure that the Uri is valid to prevent bug #508982. This
 			// has to be done here for long-time Tomboy users who won't go
 			// through the CreateStartNotes () process.
-			if (StartNoteUri == String.Empty) {
+			if (StartNoteUri == String.Empty ||
+			    FindByUri(StartNoteUri) == null) {
 				// Attempt to find an existing Start Here note
 				Note start_note = Find (Catalog.GetString ("Start Here"));
 				if (start_note != null)
@@ -375,7 +376,8 @@ public NoteManager (string directory) :
 			if (note_template != null) {
 				// Use the body from the "New Note Template" note
 				string xml_content =
-					note_template.XmlContent.Replace (NoteTemplateTitle, title);
+					note_template.XmlContent.Replace (NoteTemplateTitle,
+					                                  XmlEncoder.Encode (title));
 				return CreateNewNote (title, xml_content, guid);
 			}
 			
